containertools.get_first_element_starting_strictly_before_offset
================================================================

.. autofunction:: abjad.tools.containertools.get_first_element_starting_strictly_before_offset.get_first_element_starting_strictly_before_offset
   :noindex:
